#!/bin/bash -xe

SRCDIR=${PWD}
TARGET=$1

usage()
{
    echo "Usage: $0 [cross|local]"
}

if [ -f "/lib64/libc.so.6" ]; then
    LIBC_SO_PATH=/lib64/libc.so.6
elif [ -f "/lib32/libc.so.6" ]; then
    LIBC_SO_PATH=/lib32/libc.so.6
elif [ -f "/lib/x86_64-linux-gnu/libc.so.6" ]; then
    LIBC_SO_PATH=/lib/x86_64-linux-gnu/libc.so.6
elif [ -f "/lib/libc.so.6" ]; then
    LIBC_SO_PATH=/lib/libc.so.6
else
    LIBC_SO_PATH=/lib/libc.so.6
fi

GLIBC_VERSION=`${LIBC_SO_PATH} | head -n 1 | sed -e 's/.*\(version [0-9]\.[0-9]*\).*/\1/' | sed -e 's/version //g'`
if [ "x${GLIBC_VERSION}" = "x" ]; then
    echo "failed to detect glibc version. check host os environment."
    exit 1
fi

# 2.5 for CentOS 5.x
# 2.12 for CentOS 6.x
# 2.15 for Ubuntu 12.04 LTS
echo "detected glibc version = ${GLIBC_VERSION}"

case "${TARGET}" in
    cross)
        DESTDIR=${SRCDIR}/../../export/arm-sony-linux-gnueabi-armv7a
        DESTLIBDIR=${SRCDIR}/../../export/arm-sony-linux-gnueabi-armv7a/lib
        which arm-sony-linux-gnueabi-armv7a-gcc
        which arm-sony-linux-gnueabi-armv7a-g++

        HOST=arm-linux
        which arm-sony-linux-gnueabi-armv7a-gcc
        CC=arm-sony-linux-gnueabi-armv7a-gcc
        CPP=arm-sony-linux-gnueabi-armv7a-cpp
        CXX=arm-sony-linux-gnueabi-armv7a-g++
        LD=arm-sony-linux-gnueabi-armv7a-ld
        RANLIB=arm-sony-linux-gnueabi-armv7a-ranlib
        STRIP=arm-sony-linux-gnueabi-armv7a-strip
        ;;
    local)
        DESTDIR=${SRCDIR}/../../export/x86_64_pc_linux_gnu
        DESTLIBDIR=${SRCDIR}/../../export/x86_64_pc_linux_gnu/lib/${GLIBC_VERSION}

        HOST=x86_64-unknown-linux-gnu
        CC=gcc
        CPP=cpp
        CXX=g++
        LD=ld
        RANLIB=ranlib
        STRIP=strip

        CONFIG_OPT=--libdir=${DESTLIBDIR}
        ;;
    *)
        usage
        exit 0
        ;;
esac

CFLAGS=-I${DESTDIR}/include
CPPFLAGS=
CXXFLAGS=-I${DESTDIR}/include
LDFLAGS=-L${DESTLIBDIR}

CONFIG_OPT="${CONFIG_OPT} --prefix=${DESTDIR} --host=${HOST}"
CONFIG_OPT="${CONFIG_OPT} ac_cv_have_clock_monotonic=no"

./bootstrap.sh
./configure ${CONFIG_OPT} CC=${CC} CPP=${CPP} CXX=${CXX} LD=${LD} RANLIB=${RANLIB} STRIP=${STRIP} CFLAGS=${CFLAGS} CPPFLAGS=${CPPFLAGS} CXXFLAGS=${CXXFLAGS} LDFLAGS=${LDFLAGS}
make clean
make
make install
